embassy-usb-host

Crates

git

Versions

default

Flavors

parse_feedback

Function parse_feedback 

pub fn parse_feedback(speed: Speed, data: &[u8]) -> Option<f32>
Parse USB feedback endpoint response into a floating point number.

Returns the number of samples per USB frame (full-speed) or microframe (high-speed), or None if the data is invalid or the speed is unsupported.