pub fn parse_feedback(speed: Speed, data: &[u8]) -> Option<f32>Expand description
Parse USB feedback endpoint response into a floating point number.
Returns the number of samples per USB frame (full-speed) or microframe (high-speed),
or None if the data is invalid or the speed is unsupported.